==> mongodbcom-integration-broker-0.1.12.tgz: package/src/demandbase.js <==
import { loadScript } from './util'

function load (key) {
  loadScript({
    id: 'demandbase_js_lib',
    src: `//scripts.demandbase.com/${key}.min.js`
  })
}

function ready (fn) {
  const profile = getProfile()

  if (profile) return fn(false, profile)

  return setTimeout(ready, 500, fn)
}

function getProfile () {
  const { Demandbase } = window

  if (!Demandbase) return

  const { Connectors, IP } = Demandbase

  if (!Connectors) return

  const { WebForm } = Connectors

  if (!WebForm) return

  // Email domain (WebForm) takes precedence
  return WebForm.CompanyProfile || IP.CompanyProfile
}

function profile () {
  return {
    ip_address: demandbase('ip'),
    db_company_name: demandbase('hq_company_name') || demandbase('company_name'),
    db_demandbase_sid: demandbase('hq_demandbase_sid') || demandbase('demandbase_sid'),
    db_marketing_alias: demandbase('hq_marketing_alias') || demandbase('marketing_alias'),
    db_industry: demandbase('hq_industry') || demandbase('industry'),
    db_sub_industry: demandbase('hq_sub_industry'),
    db_employee_count: demandbase('employee_count'),
    db_primary_sic: demandbase('primary_sic'),
    db_street_address: demandbase('street_address'),
    db_city: demandbase('city'),
    db_state: demandbase('state') || demandbase('registry_state'),
    db_zip: demandbase('zip'),
    db_country: demandbase('country_name') || demandbase('registry_country'),
    db_country_name: demandbase('country_name'),
    db_phone: demandbase('phone'),
    db_stock_ticker: demandbase('stock_ticker'),
    db_web_site: demandbase('web_site'),
    db_annual_sales: demandbase('annual_sales'),
    db_revenue_range: demandbase('revenue_range'),
    db_employee_range: demandbase('employee_range'),
    db_b2b: demandbase('b2b'),
    db_b2c: demandbase('b2c'),
    db_traffic: demandbase('traffic'),
    db_latitude: demandbase('latitude'),
    db_longitude: demandbase('longitude'),
    db_fortune_1000: demandbase('fortune_1000'),
    db_forbes_2000: demandbase('forbes_2000'),
    db_registry_country: demandbase('registry_country'),
    db_registry_state: demandbase('registry_state'),
    db_registry_city: demandbase('registry_city'),
    db_registry_persist_state: demandbase('registry_state'),
    db_registry_persist_country: demandbase('registry_country')
  }
}

export function demandbase (key) {
  const profile = getProfile()

  if (profile) {
    return profile[key]
  }

  return ''
}

demandbase.load = load
demandbase.ready = ready
demandbase.profile = profile

==> mongodbcom-integration-broker-0.1.13.tgz: package/src/demandbase.js <==
import { loadScript } from './util'

function load (key) {
  loadScript({
    id: 'demandbase_js_lib',
    src: `//scripts.demandbase.com/${key}.min.js`
  })
}

let steps = 0

function ready (fn) {
  ++steps

  const profile = getProfile()

  if (profile || steps > 4) {
    return fn(false, profile)
  }

  return setTimeout(ready, 200, fn)
}

function getProfile () {
  const { Demandbase } = window

  if (!Demandbase) return

  const { Connectors, IP } = Demandbase

  if (!Connectors) return

  const { WebForm } = Connectors

  if (!WebForm) return

  // Email domain (WebForm) takes precedence
  return WebForm.CompanyProfile || IP.CompanyProfile
}

function profile () {
  return {
    ip_address: demandbase('ip'),
    db_company_name: demandbase('hq_company_name') || demandbase('company_name'),
    db_demandbase_sid: demandbase('hq_demandbase_sid') || demandbase('demandbase_sid'),
    db_marketing_alias: demandbase('hq_marketing_alias') || demandbase('marketing_alias'),
    db_industry: demandbase('hq_industry') || demandbase('industry'),
    db_sub_industry: demandbase('hq_sub_industry'),
    db_employee_count: demandbase('employee_count'),
    db_primary_sic: demandbase('primary_sic'),
    db_street_address: demandbase('street_address'),
    db_city: demandbase('city'),
    db_state: demandbase('state') || demandbase('registry_state'),
    db_zip: demandbase('zip'),
    db_country: demandbase('country_name') || demandbase('registry_country'),
    db_country_name: demandbase('country_name'),
    db_phone: demandbase('phone'),
    db_stock_ticker: demandbase('stock_ticker'),
    db_web_site: demandbase('web_site'),
    db_annual_sales: demandbase('annual_sales'),
    db_revenue_range: demandbase('revenue_range'),
    db_employee_range: demandbase('employee_range'),
    db_b2b: demandbase('b2b'),
    db_b2c: demandbase('b2c'),
    db_traffic: demandbase('traffic'),
    db_latitude: demandbase('latitude'),
    db_longitude: demandbase('longitude'),
    db_fortune_1000: demandbase('fortune_1000'),
    db_forbes_2000: demandbase('forbes_2000'),
    db_registry_country: demandbase('registry_country'),
    db_registry_state: demandbase('registry_state'),
    db_registry_city: demandbase('registry_city'),
    db_registry_persist_state: demandbase('registry_state'),
    db_registry_persist_country: demandbase('registry_country')
  }
}

export function demandbase (key) {
  const profile = getProfile()

  if (profile) {
    return profile[key]
  }

  return ''
}

demandbase.load = load
demandbase.ready = ready
demandbase.profile = profile
